@@ -5,11 +5,10 @@ use std::{
     time,
 };
 
-use bytes::Bytes;
-
 use crate::codec::{AsyncRead, AsyncWrite};
 use crate::framed::{ReadTask, State as IoState, WriteTask};
 use crate::service::Service;
+use crate::util::Bytes;
 
 use crate::http;
 use crate::http::body::{BodySize, MessageBody, ResponseBody};
@@ -118,15 +117,15 @@ where
             config.read_hw,
             config.write_hw,
             config.lw,
-            config.client_disconnect as u16,
+            config.client_disconnect,
         );
 
         let mut expire = config.timer_h1.now();
         let io = Rc::new(RefCell::new(io));
 
         // slow-request timer
-        if config.client_timeout != 0 {
-            expire += time::Duration::from_secs(config.client_timeout);
+        if config.client_timeout.non_zero() {
+            expire += std::time::Duration::from(config.client_timeout);
             config.timer_h1.register(expire, expire, &state);
         }
 
@@ -537,9 +536,9 @@ where
 
     fn reset_keepalive(&mut self) {
         // re-register keep-alive
-        if self.flags.contains(Flags::KEEPALIVE) && self.config.keep_alive.as_secs() != 0
-        {
-            let expire = self.config.timer_h1.now() + self.config.keep_alive;
+        if self.flags.contains(Flags::KEEPALIVE) && self.config.keep_alive.non_zero() {
+            let expire = self.config.timer_h1.now()
+                + std::time::Duration::from(self.config.keep_alive);
             if expire != self.expire {
                 self.config
                     .timer_h1
@@ -733,7 +732,6 @@ mod tests {
     use std::sync::atomic::{AtomicBool, AtomicUsize, Ordering};
     use std::{cell::Cell, io, sync::Arc};
 
-    use bytes::{Bytes, BytesMut};
     use rand::Rng;
 
     use super::*;
@@ -741,7 +739,8 @@ mod tests {
     use crate::http::h1::{ClientCodec, ExpectHandler, UpgradeHandler};
     use crate::http::{body, Request, ResponseHead, StatusCode};
     use crate::service::{boxed, fn_service, IntoService};
-    use crate::{codec::Decoder, rt::time::sleep, testing::Io, util::lazy, util::next};
+    use crate::util::{lazy, next, Bytes, BytesMut};
+    use crate::{codec::Decoder, testing::Io, time::sleep, time::Millis};
 
     const BUFFER_SIZE: usize = 32_768;
 
@@ -816,18 +815,20 @@ mod tests {
                 }),
                 ExpectHandler,
                 None,
-                Some(boxed::service(crate::into_service(move |(req, _)| {
-                    data2.set(true);
-                    Box::pin(async move { Ok(req) })
-                }))),
+                Some(boxed::service(crate::service::into_service(
+                    move |(req, _)| {
+                        data2.set(true);
+                        Box::pin(async move { Ok(req) })
+                    },
+                ))),
             )),
             None,
             None,
         );
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
 
         assert!(lazy(|cx| Pin::new(&mut h1).poll(cx)).await.is_ready());
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
 
         client.local_buffer(|buf| assert_eq!(&buf[..15], b"HTTP/1.0 200 OK"));
         client.close().await;
@@ -843,11 +844,11 @@ mod tests {
         let mut h1 = h1(server, |_| {
             Box::pin(async { Ok::<_, io::Error>(Response::Ok().finish()) })
         });
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
 
         assert!(lazy(|cx| Pin::new(&mut h1).poll(cx)).await.is_ready());
         assert!(!h1.inner.state.is_open());
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
 
         client
             .local_buffer(|buf| assert_eq!(&buf[..26], b"HTTP/1.1 400 Bad Request\r\n"));
@@ -898,7 +899,7 @@ mod tests {
         });
 
         client.write("GET /test HTTP/1.1\r\ncontent-length: 5\r\n\r\n");
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
         client.write("xxxxx");
 
         let mut buf = client.read().await.unwrap();
@@ -922,7 +923,7 @@ mod tests {
         client.remote_buffer_cap(4096);
         let mut decoder = ClientCodec::default();
         spawn_h1(server, |_| async {
-            sleep(time::Duration::from_millis(100)).await;
+            sleep(Millis(100)).await;
             Ok::<_, io::Error>(Response::Ok().finish())
         });
 
@@ -934,7 +935,7 @@ mod tests {
 
         client.write("GET /test HTTP/1.1\r\n\r\n");
         client.write("GET /test HTTP/1.1\r\n\r\n");
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
         client.write("GET /test HTTP/1.1\r\n\r\n");
 
         let mut buf = client.read().await.unwrap();
@@ -999,10 +1000,10 @@ mod tests {
             .collect::<String>();
         client.write("GET /test HTTP/1.1\r\nContent-Length: ");
         client.write(data);
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
 
         assert!(lazy(|cx| Pin::new(&mut h1).poll(cx)).await.is_pending());
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
         assert!(lazy(|cx| Pin::new(&mut h1).poll(cx)).await.is_ready());
         assert!(!h1.inner.state.is_open());
 
@@ -1025,13 +1026,13 @@ mod tests {
                 let _ = next(&mut pl).await.unwrap().unwrap();
                 m.store(true, Ordering::Relaxed);
                 // sleep
-                sleep(time::Duration::from_secs(999_999)).await;
+                sleep(Millis(999_999_000)).await;
                 Ok::<_, io::Error>(Response::Ok().finish())
             }
         });
 
         client.write("GET /test HTTP/1.1\r\nContent-Length: 1048576\r\n\r\n");
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
 
         // buf must be consumed
         assert_eq!(client.remote_buffer(|buf| buf.len()), 0);
@@ -1041,7 +1042,7 @@ mod tests {
             (0..1_048_576).map(|_| rand::random::<u8>()).collect();
         client.write(random_bytes);
 
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
         assert!(client.remote_buffer(|buf| buf.len()) > 1_048_576 - BUFFER_SIZE * 3);
         assert!(mark.load(Ordering::Relaxed));
     }
@@ -1084,7 +1085,7 @@ mod tests {
         // do not allow to write to socket
         client.remote_buffer_cap(0);
         client.write("GET /test HTTP/1.1\r\n\r\n");
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
         assert!(lazy(|cx| Pin::new(&mut h1).poll(cx)).await.is_pending());
 
         // buf must be consumed
@@ -1097,7 +1098,7 @@ mod tests {
         assert_eq!(state.write().with_buf(|buf| buf.len()), 65629);
 
         client.remote_buffer_cap(65536);
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
         assert_eq!(state.write().with_buf(|buf| buf.len()), 93);
 
         assert!(lazy(|cx| Pin::new(&mut h1).poll(cx)).await.is_pending());
@@ -1139,7 +1140,7 @@ mod tests {
         });
 
         client.write("GET /test HTTP/1.1\r\n\r\n");
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
         assert!(lazy(|cx| Pin::new(&mut h1).poll(cx)).await.is_pending());
 
         // http message must be consumed
@@ -1151,7 +1152,7 @@ mod tests {
         assert!(lazy(|cx| Pin::new(&mut h1).poll(cx)).await.is_pending());
 
         client.close().await;
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
         assert!(lazy(|cx| Pin::new(&mut h1).poll(cx)).await.is_ready());
     }
 
@@ -1166,10 +1167,10 @@ mod tests {
                 Err::<Response<()>, _>(io::Error::new(io::ErrorKind::Other, "error"))
             })
         });
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
 
         assert!(lazy(|cx| Pin::new(&mut h1).poll(cx)).await.is_ready());
-        sleep(time::Duration::from_millis(50)).await;
+        sleep(Millis(50)).await;
         assert!(h1.inner.state.is_io_err());
         let buf = client.local_buffer(|buf| buf.split().freeze());
         assert_eq!(&buf[..28], b"HTTP/1.1 500 Internal Server");
