@@ -1,7 +1,6 @@
 use std::task::{Context, Poll};
 use std::{future::Future, marker::PhantomData, net, pin::Pin, rc::Rc};
 
-use bytes::Bytes;
 use h2::server::{self, Handshake};
 use log::error;
 
@@ -13,10 +12,12 @@ use crate::http::helpers::DataFactory;
 use crate::http::request::Request;
 use crate::http::response::Response;
 use crate::rt::net::TcpStream;
-use crate::{
+use crate::service::{
     fn_factory, fn_service, pipeline_factory, IntoServiceFactory, Service,
     ServiceFactory,
 };
+use crate::time::Millis;
+use crate::util::Bytes;
 
 use super::dispatcher::Dispatcher;
 
@@ -26,7 +27,7 @@ pub struct H2Service<T, S, B> {
     cfg: ServiceConfig,
     on_connect: Option<Rc<dyn Fn(&T) -> Box<dyn DataFactory>>>,
     #[allow(dead_code)]
-    handshake_timeout: u64,
+    handshake_timeout: Millis,
     _t: PhantomData<(T, B)>,
 }
 
@@ -47,7 +48,7 @@ where
         H2Service {
             on_connect: None,
             srv: service.into_factory(),
-            handshake_timeout: (cfg.0.ssl_handshake_timeout as u64) * 1000,
+            handshake_timeout: cfg.0.ssl_handshake_timeout,
             _t: PhantomData,
             cfg,
         }
@@ -98,7 +99,7 @@ mod openssl {
     use crate::server::SslError;
 
     use super::*;
-    use crate::{fn_factory, fn_service};
+    use crate::service::{fn_factory, fn_service};
 
     impl<S, B> H2Service<SslStream<TcpStream>, S, B>
     where
@@ -265,7 +266,7 @@ where
                 self.config.clone(),
                 addr,
                 self.on_connect.as_ref().map(|f| f(&io)),
-                server::handshake(io),
+                server::Builder::new().handshake(io),
             ),
         }
     }
