@@ -4,8 +4,8 @@ use std::{thread, time::Duration};
 #[cfg(feature = "openssl")]
 use open_ssl::ssl::SslAcceptorBuilder;
 
-use ntex::server::TestServer;
 use ntex::web::{self, App, HttpResponse, HttpServer};
+use ntex::{server::TestServer, time::Seconds};
 
 #[cfg(unix)]
 #[ntex::test]
@@ -28,9 +28,9 @@ async fn test_run() {
             .maxconn(10)
             .maxconnrate(10)
             .keep_alive(10)
-            .client_timeout(5000)
-            .disconnect_timeout(1000)
-            .ssl_handshake_timeout(1000)
+            .client_timeout(Seconds(5))
+            .disconnect_timeout(Seconds(1))
+            .ssl_handshake_timeout(Seconds(1))
             .server_hostname("localhost")
             .stop_runtime()
             .disable_signals()
@@ -47,11 +47,7 @@ async fn test_run() {
     use ntex::http::client;
 
     let client = client::Client::build()
-        .connector(
-            client::Connector::default()
-                .timeout(Duration::from_millis(100))
-                .finish(),
-        )
+        .connector(client::Connector::default().timeout(Seconds(100)).finish())
         .finish();
 
     let host = format!("http://{}", addr);
@@ -90,10 +86,10 @@ fn client() -> ntex::http::client::Client {
         .map_err(|e| log::error!("Cannot set alpn protocol: {:?}", e));
 
     ntex::http::client::Client::build()
-        .timeout(Duration::from_millis(30000))
+        .timeout(Seconds(30))
         .connector(
             ntex::http::client::Connector::default()
-                .timeout(Duration::from_millis(30000))
+                .timeout(Seconds(30))
                 .openssl(builder.build())
                 .finish(),
         )
@@ -122,7 +118,7 @@ async fn test_openssl() {
                 )))
             })
             .workers(1)
-            .shutdown_timeout(1)
+            .shutdown_timeout(Seconds(1))
             .stop_runtime()
             .disable_signals()
             .bind_openssl(format!("{}", addr), builder)
@@ -183,7 +179,7 @@ async fn test_rustls() {
                 )))
             })
             .workers(1)
-            .shutdown_timeout(1)
+            .shutdown_timeout(Seconds(1))
             .stop_runtime()
             .disable_signals()
             .bind_rustls(format!("{}", addr), config)
@@ -224,7 +220,7 @@ async fn test_bind_uds() {
                 )
             })
             .workers(1)
-            .shutdown_timeout(1)
+            .shutdown_timeout(Seconds(1))
             .stop_runtime()
             .disable_signals()
             .bind_uds("/tmp/uds-test")
@@ -242,7 +238,7 @@ async fn test_bind_uds() {
     let client = client::Client::build()
         .connector(
             client::Connector::default()
-                .connector(ntex::fn_service(|_| async {
+                .connector(ntex::service::fn_service(|_| async {
                     let stream =
                         ntex::rt::net::UnixStream::connect("/tmp/uds-test").await?;
                     Ok((stream, ntex::http::Protocol::Http1))
@@ -278,7 +274,7 @@ async fn test_listen_uds() {
                 )
             })
             .workers(1)
-            .shutdown_timeout(1)
+            .shutdown_timeout(Seconds(1))
             .stop_runtime()
             .disable_signals()
             .listen_uds(lst)
@@ -296,7 +292,7 @@ async fn test_listen_uds() {
     let client = client::Client::build()
         .connector(
             client::Connector::default()
-                .connector(ntex::fn_service(|_| async {
+                .connector(ntex::service::fn_service(|_| async {
                     let stream =
                         ntex::rt::net::UnixStream::connect("/tmp/uds-test2").await?;
                     Ok((stream, ntex::http::Protocol::Http1))
